# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGroupProvisionedUsersResult',
    'AwaitableGetGroupProvisionedUsersResult',
    'get_group_provisioned_users',
    'get_group_provisioned_users_output',
]

@pulumi.output_type
class GetGroupProvisionedUsersResult:
    """
    A collection of values returned by getGroupProvisionedUsers.
    """
    def __init__(__self__, active=None, blocked=None, created_after=None, created_before=None, id=None, provisioned_users=None, search=None, username=None):
        if active and not isinstance(active, bool):
            raise TypeError("Expected argument 'active' to be a bool")
        pulumi.set(__self__, "active", active)
        if blocked and not isinstance(blocked, bool):
            raise TypeError("Expected argument 'blocked' to be a bool")
        pulumi.set(__self__, "blocked", blocked)
        if created_after and not isinstance(created_after, str):
            raise TypeError("Expected argument 'created_after' to be a str")
        pulumi.set(__self__, "created_after", created_after)
        if created_before and not isinstance(created_before, str):
            raise TypeError("Expected argument 'created_before' to be a str")
        pulumi.set(__self__, "created_before", created_before)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if provisioned_users and not isinstance(provisioned_users, list):
            raise TypeError("Expected argument 'provisioned_users' to be a list")
        pulumi.set(__self__, "provisioned_users", provisioned_users)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def active(self) -> Optional[bool]:
        """
        Return only active provisioned users.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter
    def blocked(self) -> Optional[bool]:
        """
        Return only blocked provisioned users.
        """
        return pulumi.get(self, "blocked")

    @property
    @pulumi.getter(name="createdAfter")
    def created_after(self) -> Optional[str]:
        """
        Return only provisioned users created on or after the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
        """
        return pulumi.get(self, "created_after")

    @property
    @pulumi.getter(name="createdBefore")
    def created_before(self) -> Optional[str]:
        """
        Return only provisioned users created on or before the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
        """
        return pulumi.get(self, "created_before")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID or URL-encoded path of the group.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="provisionedUsers")
    def provisioned_users(self) -> Optional[Sequence['outputs.GetGroupProvisionedUsersProvisionedUserResult']]:
        """
        The list of provisioned users.
        """
        return pulumi.get(self, "provisioned_users")

    @property
    @pulumi.getter
    def search(self) -> Optional[str]:
        """
        The search query to filter the provisioned users.
        """
        return pulumi.get(self, "search")

    @property
    @pulumi.getter
    def username(self) -> Optional[str]:
        """
        The username of the provisioned user.
        """
        return pulumi.get(self, "username")


class AwaitableGetGroupProvisionedUsersResult(GetGroupProvisionedUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupProvisionedUsersResult(
            active=self.active,
            blocked=self.blocked,
            created_after=self.created_after,
            created_before=self.created_before,
            id=self.id,
            provisioned_users=self.provisioned_users,
            search=self.search,
            username=self.username)


def get_group_provisioned_users(active: Optional[bool] = None,
                                blocked: Optional[bool] = None,
                                created_after: Optional[str] = None,
                                created_before: Optional[str] = None,
                                id: Optional[str] = None,
                                provisioned_users: Optional[Sequence[Union['GetGroupProvisionedUsersProvisionedUserArgs', 'GetGroupProvisionedUsersProvisionedUserArgsDict']]] = None,
                                search: Optional[str] = None,
                                username: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupProvisionedUsersResult:
    """
    The `get_group_provisioned_users` data source allows details of the provisioned users of a given group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-provisioned-users)


    :param bool active: Return only active provisioned users.
    :param bool blocked: Return only blocked provisioned users.
    :param str created_after: Return only provisioned users created on or after the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
    :param str created_before: Return only provisioned users created on or before the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
    :param str id: The ID or URL-encoded path of the group.
    :param Sequence[Union['GetGroupProvisionedUsersProvisionedUserArgs', 'GetGroupProvisionedUsersProvisionedUserArgsDict']] provisioned_users: The list of provisioned users.
    :param str search: The search query to filter the provisioned users.
    :param str username: The username of the provisioned user.
    """
    __args__ = dict()
    __args__['active'] = active
    __args__['blocked'] = blocked
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['id'] = id
    __args__['provisionedUsers'] = provisioned_users
    __args__['search'] = search
    __args__['username'] = username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupProvisionedUsers:getGroupProvisionedUsers', __args__, opts=opts, typ=GetGroupProvisionedUsersResult).value

    return AwaitableGetGroupProvisionedUsersResult(
        active=pulumi.get(__ret__, 'active'),
        blocked=pulumi.get(__ret__, 'blocked'),
        created_after=pulumi.get(__ret__, 'created_after'),
        created_before=pulumi.get(__ret__, 'created_before'),
        id=pulumi.get(__ret__, 'id'),
        provisioned_users=pulumi.get(__ret__, 'provisioned_users'),
        search=pulumi.get(__ret__, 'search'),
        username=pulumi.get(__ret__, 'username'))
def get_group_provisioned_users_output(active: Optional[pulumi.Input[Optional[bool]]] = None,
                                       blocked: Optional[pulumi.Input[Optional[bool]]] = None,
                                       created_after: Optional[pulumi.Input[Optional[str]]] = None,
                                       created_before: Optional[pulumi.Input[Optional[str]]] = None,
                                       id: Optional[pulumi.Input[str]] = None,
                                       provisioned_users: Optional[pulumi.Input[Optional[Sequence[Union['GetGroupProvisionedUsersProvisionedUserArgs', 'GetGroupProvisionedUsersProvisionedUserArgsDict']]]]] = None,
                                       search: Optional[pulumi.Input[Optional[str]]] = None,
                                       username: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupProvisionedUsersResult]:
    """
    The `get_group_provisioned_users` data source allows details of the provisioned users of a given group.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/groups/#list-provisioned-users)


    :param bool active: Return only active provisioned users.
    :param bool blocked: Return only blocked provisioned users.
    :param str created_after: Return only provisioned users created on or after the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
    :param str created_before: Return only provisioned users created on or before the specified date. Expected in ISO 8601 format (YYYY-MM-DDTHH:MM:SSZ).
    :param str id: The ID or URL-encoded path of the group.
    :param Sequence[Union['GetGroupProvisionedUsersProvisionedUserArgs', 'GetGroupProvisionedUsersProvisionedUserArgsDict']] provisioned_users: The list of provisioned users.
    :param str search: The search query to filter the provisioned users.
    :param str username: The username of the provisioned user.
    """
    __args__ = dict()
    __args__['active'] = active
    __args__['blocked'] = blocked
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['id'] = id
    __args__['provisionedUsers'] = provisioned_users
    __args__['search'] = search
    __args__['username'] = username
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupProvisionedUsers:getGroupProvisionedUsers', __args__, opts=opts, typ=GetGroupProvisionedUsersResult)
    return __ret__.apply(lambda __response__: GetGroupProvisionedUsersResult(
        active=pulumi.get(__response__, 'active'),
        blocked=pulumi.get(__response__, 'blocked'),
        created_after=pulumi.get(__response__, 'created_after'),
        created_before=pulumi.get(__response__, 'created_before'),
        id=pulumi.get(__response__, 'id'),
        provisioned_users=pulumi.get(__response__, 'provisioned_users'),
        search=pulumi.get(__response__, 'search'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['MemberRoleArgs', 'MemberRole']

@pulumi.input_type
class MemberRoleArgs:
    def __init__(__self__, *,
                 base_access_level: pulumi.Input[str],
                 enabled_permissions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 description: Optional[pulumi.Input[str]] = None,
                 group_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MemberRole resource.
        :param pulumi.Input[str] base_access_level: The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] enabled_permissions: All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        :param pulumi.Input[str] description: Description for the member role.
        :param pulumi.Input[str] group_path: Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        :param pulumi.Input[str] name: Name for the member role.
        """
        pulumi.set(__self__, "base_access_level", base_access_level)
        pulumi.set(__self__, "enabled_permissions", enabled_permissions)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_path is not None:
            pulumi.set(__self__, "group_path", group_path)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="baseAccessLevel")
    def base_access_level(self) -> pulumi.Input[str]:
        """
        The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        """
        return pulumi.get(self, "base_access_level")

    @base_access_level.setter
    def base_access_level(self, value: pulumi.Input[str]):
        pulumi.set(self, "base_access_level", value)

    @property
    @pulumi.getter(name="enabledPermissions")
    def enabled_permissions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        """
        return pulumi.get(self, "enabled_permissions")

    @enabled_permissions.setter
    def enabled_permissions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "enabled_permissions", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description for the member role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupPath")
    def group_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        """
        return pulumi.get(self, "group_path")

    @group_path.setter
    def group_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_path", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name for the member role.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _MemberRoleState:
    def __init__(__self__, *,
                 base_access_level: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 edit_path: Optional[pulumi.Input[str]] = None,
                 enabled_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 group_path: Optional[pulumi.Input[str]] = None,
                 iid: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MemberRole resources.
        :param pulumi.Input[str] base_access_level: The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        :param pulumi.Input[str] created_at: Timestamp of when the member role was created. Only available with GitLab version 17.3 or higher.
        :param pulumi.Input[str] description: Description for the member role.
        :param pulumi.Input[str] edit_path: The Web UI path to edit the member role
        :param pulumi.Input[Sequence[pulumi.Input[str]]] enabled_permissions: All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        :param pulumi.Input[str] group_path: Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        :param pulumi.Input[int] iid: The id integer value extracted from the `id` attribute
        :param pulumi.Input[str] name: Name for the member role.
        """
        if base_access_level is not None:
            pulumi.set(__self__, "base_access_level", base_access_level)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if edit_path is not None:
            pulumi.set(__self__, "edit_path", edit_path)
        if enabled_permissions is not None:
            pulumi.set(__self__, "enabled_permissions", enabled_permissions)
        if group_path is not None:
            pulumi.set(__self__, "group_path", group_path)
        if iid is not None:
            pulumi.set(__self__, "iid", iid)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="baseAccessLevel")
    def base_access_level(self) -> Optional[pulumi.Input[str]]:
        """
        The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        """
        return pulumi.get(self, "base_access_level")

    @base_access_level.setter
    def base_access_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "base_access_level", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp of when the member role was created. Only available with GitLab version 17.3 or higher.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description for the member role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="editPath")
    def edit_path(self) -> Optional[pulumi.Input[str]]:
        """
        The Web UI path to edit the member role
        """
        return pulumi.get(self, "edit_path")

    @edit_path.setter
    def edit_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edit_path", value)

    @property
    @pulumi.getter(name="enabledPermissions")
    def enabled_permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        """
        return pulumi.get(self, "enabled_permissions")

    @enabled_permissions.setter
    def enabled_permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "enabled_permissions", value)

    @property
    @pulumi.getter(name="groupPath")
    def group_path(self) -> Optional[pulumi.Input[str]]:
        """
        Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        """
        return pulumi.get(self, "group_path")

    @group_path.setter
    def group_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_path", value)

    @property
    @pulumi.getter
    def iid(self) -> Optional[pulumi.Input[int]]:
        """
        The id integer value extracted from the `id` attribute
        """
        return pulumi.get(self, "iid")

    @iid.setter
    def iid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "iid", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name for the member role.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class MemberRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_access_level: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 group_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `MemberRole` resource allows to manage the lifecycle of a custom member role.

        Custom roles allow an organization to create user roles with the precise privileges and permissions required for that organization’s needs.

        > This resource requires an Ultimate license.

        > Most custom roles are considered billable users that use a seat. [Custom roles billing and seat usage](https://docs.gitlab.com/user/custom_roles/#billing-and-seat-usage)

        > There can be only 10 custom roles on your instance or namespace. See [issue 450929](https://gitlab.com/gitlab-org/gitlab/-/issues/450929) for more details.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationmemberrolecreate)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_member_role`. For example:

        terraform

        import {

          to = gitlab_member_role.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab member role can be imported using the id made up of `gid://gitlab/MemberRole/<ID>` e.g.

        ```sh
        $ pulumi import gitlab:index/memberRole:MemberRole example 'gid://gitlab/MemberRole/123'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] base_access_level: The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        :param pulumi.Input[str] description: Description for the member role.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] enabled_permissions: All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        :param pulumi.Input[str] group_path: Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        :param pulumi.Input[str] name: Name for the member role.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MemberRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `MemberRole` resource allows to manage the lifecycle of a custom member role.

        Custom roles allow an organization to create user roles with the precise privileges and permissions required for that organization’s needs.

        > This resource requires an Ultimate license.

        > Most custom roles are considered billable users that use a seat. [Custom roles billing and seat usage](https://docs.gitlab.com/user/custom_roles/#billing-and-seat-usage)

        > There can be only 10 custom roles on your instance or namespace. See [issue 450929](https://gitlab.com/gitlab-org/gitlab/-/issues/450929) for more details.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationmemberrolecreate)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_member_role`. For example:

        terraform

        import {

          to = gitlab_member_role.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab member role can be imported using the id made up of `gid://gitlab/MemberRole/<ID>` e.g.

        ```sh
        $ pulumi import gitlab:index/memberRole:MemberRole example 'gid://gitlab/MemberRole/123'
        ```

        :param str resource_name: The name of the resource.
        :param MemberRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MemberRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_access_level: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 group_path: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MemberRoleArgs.__new__(MemberRoleArgs)

            if base_access_level is None and not opts.urn:
                raise TypeError("Missing required property 'base_access_level'")
            __props__.__dict__["base_access_level"] = base_access_level
            __props__.__dict__["description"] = description
            if enabled_permissions is None and not opts.urn:
                raise TypeError("Missing required property 'enabled_permissions'")
            __props__.__dict__["enabled_permissions"] = enabled_permissions
            __props__.__dict__["group_path"] = group_path
            __props__.__dict__["name"] = name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["edit_path"] = None
            __props__.__dict__["iid"] = None
        super(MemberRole, __self__).__init__(
            'gitlab:index/memberRole:MemberRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            base_access_level: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            edit_path: Optional[pulumi.Input[str]] = None,
            enabled_permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            group_path: Optional[pulumi.Input[str]] = None,
            iid: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'MemberRole':
        """
        Get an existing MemberRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] base_access_level: The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        :param pulumi.Input[str] created_at: Timestamp of when the member role was created. Only available with GitLab version 17.3 or higher.
        :param pulumi.Input[str] description: Description for the member role.
        :param pulumi.Input[str] edit_path: The Web UI path to edit the member role
        :param pulumi.Input[Sequence[pulumi.Input[str]]] enabled_permissions: All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        :param pulumi.Input[str] group_path: Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        :param pulumi.Input[int] iid: The id integer value extracted from the `id` attribute
        :param pulumi.Input[str] name: Name for the member role.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MemberRoleState.__new__(_MemberRoleState)

        __props__.__dict__["base_access_level"] = base_access_level
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["edit_path"] = edit_path
        __props__.__dict__["enabled_permissions"] = enabled_permissions
        __props__.__dict__["group_path"] = group_path
        __props__.__dict__["iid"] = iid
        __props__.__dict__["name"] = name
        return MemberRole(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="baseAccessLevel")
    def base_access_level(self) -> pulumi.Output[str]:
        """
        The base access level for the custom role. Valid values are: `DEVELOPER`, `GUEST`, `MAINTAINER`, `MINIMAL_ACCESS`, `OWNER`, `REPORTER`
        """
        return pulumi.get(self, "base_access_level")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Timestamp of when the member role was created. Only available with GitLab version 17.3 or higher.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description for the member role.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="editPath")
    def edit_path(self) -> pulumi.Output[str]:
        """
        The Web UI path to edit the member role
        """
        return pulumi.get(self, "edit_path")

    @property
    @pulumi.getter(name="enabledPermissions")
    def enabled_permissions(self) -> pulumi.Output[Sequence[str]]:
        """
        All permissions enabled for the custom role. Valid values are: `ADMIN_CICD_VARIABLES`, `ADMIN_COMPLIANCE_FRAMEWORK`, `ADMIN_GROUP_MEMBER`, `ADMIN_INTEGRATIONS`, `ADMIN_MERGE_REQUEST`, `ADMIN_PROTECTED_BRANCH`, `ADMIN_PUSH_RULES`, `ADMIN_RUNNERS`, `ADMIN_TERRAFORM_STATE`, `ADMIN_VULNERABILITY`, `ADMIN_WEB_HOOK`, `ARCHIVE_PROJECT`, `MANAGE_DEPLOY_TOKENS`, `MANAGE_GROUP_ACCESS_TOKENS`, `MANAGE_MERGE_REQUEST_SETTINGS`, `MANAGE_PROJECT_ACCESS_TOKENS`, `MANAGE_SECURITY_POLICY_LINK`, `READ_ADMIN_CICD`, `READ_ADMIN_DASHBOARD`, `READ_CODE`, `READ_COMPLIANCE_DASHBOARD`, `READ_CRM_CONTACT`, `READ_DEPENDENCY`, `READ_RUNNERS`, `READ_VULNERABILITY`, `REMOVE_GROUP`, `REMOVE_PROJECT`
        """
        return pulumi.get(self, "enabled_permissions")

    @property
    @pulumi.getter(name="groupPath")
    def group_path(self) -> pulumi.Output[str]:
        """
        Full path of the namespace to create the member role in. **Required for SAAS** **Not allowed for self-managed**
        """
        return pulumi.get(self, "group_path")

    @property
    @pulumi.getter
    def iid(self) -> pulumi.Output[int]:
        """
        The id integer value extracted from the `id` attribute
        """
        return pulumi.get(self, "iid")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name for the member role.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectMilestonesResult',
    'AwaitableGetProjectMilestonesResult',
    'get_project_milestones',
    'get_project_milestones_output',
]

@pulumi.output_type
class GetProjectMilestonesResult:
    """
    A collection of values returned by getProjectMilestones.
    """
    def __init__(__self__, id=None, iids=None, include_parent_milestones=None, milestones=None, project=None, search=None, state=None, title=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iids and not isinstance(iids, list):
            raise TypeError("Expected argument 'iids' to be a list")
        pulumi.set(__self__, "iids", iids)
        if include_parent_milestones and not isinstance(include_parent_milestones, bool):
            raise TypeError("Expected argument 'include_parent_milestones' to be a bool")
        pulumi.set(__self__, "include_parent_milestones", include_parent_milestones)
        if milestones and not isinstance(milestones, list):
            raise TypeError("Expected argument 'milestones' to be a list")
        pulumi.set(__self__, "milestones", milestones)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def iids(self) -> Optional[Sequence[int]]:
        """
        Return only the milestones having the given `iid` (Note: ignored if `include_parent_milestones` is set as `true`).
        """
        return pulumi.get(self, "iids")

    @property
    @pulumi.getter(name="includeParentMilestones")
    def include_parent_milestones(self) -> Optional[bool]:
        """
        Include group milestones from parent group and its ancestors.
        """
        return pulumi.get(self, "include_parent_milestones")

    @property
    @pulumi.getter
    def milestones(self) -> Sequence['outputs.GetProjectMilestonesMilestoneResult']:
        """
        List of milestones from a project.
        """
        return pulumi.get(self, "milestones")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def search(self) -> Optional[str]:
        """
        Return only milestones with a title or description matching the provided string.
        """
        return pulumi.get(self, "search")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        Return only `active` or `closed` milestones.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def title(self) -> Optional[str]:
        """
        Return only the milestones having the given `title`.
        """
        return pulumi.get(self, "title")


class AwaitableGetProjectMilestonesResult(GetProjectMilestonesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMilestonesResult(
            id=self.id,
            iids=self.iids,
            include_parent_milestones=self.include_parent_milestones,
            milestones=self.milestones,
            project=self.project,
            search=self.search,
            state=self.state,
            title=self.title)


def get_project_milestones(iids: Optional[Sequence[int]] = None,
                           include_parent_milestones: Optional[bool] = None,
                           project: Optional[str] = None,
                           search: Optional[str] = None,
                           state: Optional[str] = None,
                           title: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMilestonesResult:
    """
    The `get_project_milestones` data source allows get details of a project milestones.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/milestones/)


    :param Sequence[int] iids: Return only the milestones having the given `iid` (Note: ignored if `include_parent_milestones` is set as `true`).
    :param bool include_parent_milestones: Include group milestones from parent group and its ancestors.
    :param str project: The ID or URL-encoded path of the project owned by the authenticated user.
    :param str search: Return only milestones with a title or description matching the provided string.
    :param str state: Return only `active` or `closed` milestones.
    :param str title: Return only the milestones having the given `title`.
    """
    __args__ = dict()
    __args__['iids'] = iids
    __args__['includeParentMilestones'] = include_parent_milestones
    __args__['project'] = project
    __args__['search'] = search
    __args__['state'] = state
    __args__['title'] = title
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectMilestones:getProjectMilestones', __args__, opts=opts, typ=GetProjectMilestonesResult).value

    return AwaitableGetProjectMilestonesResult(
        id=pulumi.get(__ret__, 'id'),
        iids=pulumi.get(__ret__, 'iids'),
        include_parent_milestones=pulumi.get(__ret__, 'include_parent_milestones'),
        milestones=pulumi.get(__ret__, 'milestones'),
        project=pulumi.get(__ret__, 'project'),
        search=pulumi.get(__ret__, 'search'),
        state=pulumi.get(__ret__, 'state'),
        title=pulumi.get(__ret__, 'title'))
def get_project_milestones_output(iids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                                  include_parent_milestones: Optional[pulumi.Input[Optional[bool]]] = None,
                                  project: Optional[pulumi.Input[str]] = None,
                                  search: Optional[pulumi.Input[Optional[str]]] = None,
                                  state: Optional[pulumi.Input[Optional[str]]] = None,
                                  title: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMilestonesResult]:
    """
    The `get_project_milestones` data source allows get details of a project milestones.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/milestones/)


    :param Sequence[int] iids: Return only the milestones having the given `iid` (Note: ignored if `include_parent_milestones` is set as `true`).
    :param bool include_parent_milestones: Include group milestones from parent group and its ancestors.
    :param str project: The ID or URL-encoded path of the project owned by the authenticated user.
    :param str search: Return only milestones with a title or description matching the provided string.
    :param str state: Return only `active` or `closed` milestones.
    :param str title: Return only the milestones having the given `title`.
    """
    __args__ = dict()
    __args__['iids'] = iids
    __args__['includeParentMilestones'] = include_parent_milestones
    __args__['project'] = project
    __args__['search'] = search
    __args__['state'] = state
    __args__['title'] = title
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectMilestones:getProjectMilestones', __args__, opts=opts, typ=GetProjectMilestonesResult)
    return __ret__.apply(lambda __response__: GetProjectMilestonesResult(
        id=pulumi.get(__response__, 'id'),
        iids=pulumi.get(__response__, 'iids'),
        include_parent_milestones=pulumi.get(__response__, 'include_parent_milestones'),
        milestones=pulumi.get(__response__, 'milestones'),
        project=pulumi.get(__response__, 'project'),
        search=pulumi.get(__response__, 'search'),
        state=pulumi.get(__response__, 'state'),
        title=pulumi.get(__response__, 'title')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectComplianceFrameworksArgs', 'ProjectComplianceFrameworks']

@pulumi.input_type
class ProjectComplianceFrameworksArgs:
    def __init__(__self__, *,
                 compliance_framework_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 project: pulumi.Input[str]):
        """
        The set of arguments for constructing a ProjectComplianceFrameworks resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compliance_framework_ids: Globally unique IDs of the compliance frameworks to assign to the project.
        :param pulumi.Input[str] project: The ID or full path of the project to change the compliance frameworks of.
        """
        pulumi.set(__self__, "compliance_framework_ids", compliance_framework_ids)
        pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="complianceFrameworkIds")
    def compliance_framework_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Globally unique IDs of the compliance frameworks to assign to the project.
        """
        return pulumi.get(self, "compliance_framework_ids")

    @compliance_framework_ids.setter
    def compliance_framework_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "compliance_framework_ids", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or full path of the project to change the compliance frameworks of.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _ProjectComplianceFrameworksState:
    def __init__(__self__, *,
                 compliance_framework_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectComplianceFrameworks resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compliance_framework_ids: Globally unique IDs of the compliance frameworks to assign to the project.
        :param pulumi.Input[str] project: The ID or full path of the project to change the compliance frameworks of.
        """
        if compliance_framework_ids is not None:
            pulumi.set(__self__, "compliance_framework_ids", compliance_framework_ids)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="complianceFrameworkIds")
    def compliance_framework_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Globally unique IDs of the compliance frameworks to assign to the project.
        """
        return pulumi.get(self, "compliance_framework_ids")

    @compliance_framework_ids.setter
    def compliance_framework_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "compliance_framework_ids", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or full path of the project to change the compliance frameworks of.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class ProjectComplianceFrameworks(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compliance_framework_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `ProjectComplianceFrameworks` resource allows to manage the lifecycle of compliance frameworks on a project.

        > This resource requires a GitLab Enterprise instance with a Premium license to set the compliance frameworks on a project.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationprojectupdatecomplianceframeworks)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        alpha = gitlab.ComplianceFramework("alpha",
            namespace_path="top-level-group",
            name="HIPAA",
            description="A HIPAA Compliance Framework",
            color="#87BEEF",
            default=False)
        beta = gitlab.ComplianceFramework("beta",
            namespace_path="top-level-group",
            name="SOC",
            description="A SOC Compliance Framework",
            color="#223344",
            default=False)
        sample = gitlab.ProjectComplianceFrameworks("sample",
            compliance_framework_ids=[
                alpha.framework_id,
                beta.framework_id,
            ],
            project="12345678")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_compliance_frameworks`. For example:

        terraform

        import {

          to = gitlab_project_compliance_frameworks.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab project compliance frameworks can be imported with a key composed of `<project_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectComplianceFrameworks:ProjectComplianceFrameworks sample "42"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compliance_framework_ids: Globally unique IDs of the compliance frameworks to assign to the project.
        :param pulumi.Input[str] project: The ID or full path of the project to change the compliance frameworks of.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectComplianceFrameworksArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectComplianceFrameworks` resource allows to manage the lifecycle of compliance frameworks on a project.

        > This resource requires a GitLab Enterprise instance with a Premium license to set the compliance frameworks on a project.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/api/graphql/reference/#mutationprojectupdatecomplianceframeworks)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        alpha = gitlab.ComplianceFramework("alpha",
            namespace_path="top-level-group",
            name="HIPAA",
            description="A HIPAA Compliance Framework",
            color="#87BEEF",
            default=False)
        beta = gitlab.ComplianceFramework("beta",
            namespace_path="top-level-group",
            name="SOC",
            description="A SOC Compliance Framework",
            color="#223344",
            default=False)
        sample = gitlab.ProjectComplianceFrameworks("sample",
            compliance_framework_ids=[
                alpha.framework_id,
                beta.framework_id,
            ],
            project="12345678")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_compliance_frameworks`. For example:

        terraform

        import {

          to = gitlab_project_compliance_frameworks.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        Gitlab project compliance frameworks can be imported with a key composed of `<project_id>`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectComplianceFrameworks:ProjectComplianceFrameworks sample "42"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectComplianceFrameworksArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectComplianceFrameworksArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compliance_framework_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectComplianceFrameworksArgs.__new__(ProjectComplianceFrameworksArgs)

            if compliance_framework_ids is None and not opts.urn:
                raise TypeError("Missing required property 'compliance_framework_ids'")
            __props__.__dict__["compliance_framework_ids"] = compliance_framework_ids
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        super(ProjectComplianceFrameworks, __self__).__init__(
            'gitlab:index/projectComplianceFrameworks:ProjectComplianceFrameworks',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compliance_framework_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'ProjectComplianceFrameworks':
        """
        Get an existing ProjectComplianceFrameworks resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] compliance_framework_ids: Globally unique IDs of the compliance frameworks to assign to the project.
        :param pulumi.Input[str] project: The ID or full path of the project to change the compliance frameworks of.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectComplianceFrameworksState.__new__(_ProjectComplianceFrameworksState)

        __props__.__dict__["compliance_framework_ids"] = compliance_framework_ids
        __props__.__dict__["project"] = project
        return ProjectComplianceFrameworks(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="complianceFrameworkIds")
    def compliance_framework_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Globally unique IDs of the compliance frameworks to assign to the project.
        """
        return pulumi.get(self, "compliance_framework_ids")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or full path of the project to change the compliance frameworks of.
        """
        return pulumi.get(self, "project")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetInstanceDeployKeysResult',
    'AwaitableGetInstanceDeployKeysResult',
    'get_instance_deploy_keys',
    'get_instance_deploy_keys_output',
]

@pulumi.output_type
class GetInstanceDeployKeysResult:
    """
    A collection of values returned by getInstanceDeployKeys.
    """
    def __init__(__self__, deploy_keys=None, id=None, public=None):
        if deploy_keys and not isinstance(deploy_keys, list):
            raise TypeError("Expected argument 'deploy_keys' to be a list")
        pulumi.set(__self__, "deploy_keys", deploy_keys)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if public and not isinstance(public, bool):
            raise TypeError("Expected argument 'public' to be a bool")
        pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter(name="deployKeys")
    def deploy_keys(self) -> Sequence['outputs.GetInstanceDeployKeysDeployKeyResult']:
        """
        The list of all deploy keys across all projects of the GitLab instance.
        """
        return pulumi.get(self, "deploy_keys")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def public(self) -> Optional[bool]:
        """
        Only return deploy keys that are public.
        """
        return pulumi.get(self, "public")


class AwaitableGetInstanceDeployKeysResult(GetInstanceDeployKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceDeployKeysResult(
            deploy_keys=self.deploy_keys,
            id=self.id,
            public=self.public)


def get_instance_deploy_keys(public: Optional[bool] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceDeployKeysResult:
    """
    The `get_instance_deploy_keys` data source allows to retrieve a list of deploy keys for a GitLab instance.

    > This data source requires administration privileges.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_keys/#list-all-deploy-keys)


    :param bool public: Only return deploy keys that are public.
    """
    __args__ = dict()
    __args__['public'] = public
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getInstanceDeployKeys:getInstanceDeployKeys', __args__, opts=opts, typ=GetInstanceDeployKeysResult).value

    return AwaitableGetInstanceDeployKeysResult(
        deploy_keys=pulumi.get(__ret__, 'deploy_keys'),
        id=pulumi.get(__ret__, 'id'),
        public=pulumi.get(__ret__, 'public'))
def get_instance_deploy_keys_output(public: Optional[pulumi.Input[Optional[bool]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceDeployKeysResult]:
    """
    The `get_instance_deploy_keys` data source allows to retrieve a list of deploy keys for a GitLab instance.

    > This data source requires administration privileges.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/deploy_keys/#list-all-deploy-keys)


    :param bool public: Only return deploy keys that are public.
    """
    __args__ = dict()
    __args__['public'] = public
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getInstanceDeployKeys:getInstanceDeployKeys', __args__, opts=opts, typ=GetInstanceDeployKeysResult)
    return __ret__.apply(lambda __response__: GetInstanceDeployKeysResult(
        deploy_keys=pulumi.get(__response__, 'deploy_keys'),
        id=pulumi.get(__response__, 'id'),
        public=pulumi.get(__response__, 'public')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetPipelineScheduleResult',
    'AwaitableGetPipelineScheduleResult',
    'get_pipeline_schedule',
    'get_pipeline_schedule_output',
]

@pulumi.output_type
class GetPipelineScheduleResult:
    """
    A collection of values returned by getPipelineSchedule.
    """
    def __init__(__self__, active=None, created_at=None, cron=None, cron_timezone=None, description=None, id=None, last_pipeline=None, next_run_at=None, owner=None, pipeline_schedule_id=None, project=None, ref=None, updated_at=None, variables=None):
        if active and not isinstance(active, bool):
            raise TypeError("Expected argument 'active' to be a bool")
        pulumi.set(__self__, "active", active)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if cron and not isinstance(cron, str):
            raise TypeError("Expected argument 'cron' to be a str")
        pulumi.set(__self__, "cron", cron)
        if cron_timezone and not isinstance(cron_timezone, str):
            raise TypeError("Expected argument 'cron_timezone' to be a str")
        pulumi.set(__self__, "cron_timezone", cron_timezone)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_pipeline and not isinstance(last_pipeline, dict):
            raise TypeError("Expected argument 'last_pipeline' to be a dict")
        pulumi.set(__self__, "last_pipeline", last_pipeline)
        if next_run_at and not isinstance(next_run_at, str):
            raise TypeError("Expected argument 'next_run_at' to be a str")
        pulumi.set(__self__, "next_run_at", next_run_at)
        if owner and not isinstance(owner, dict):
            raise TypeError("Expected argument 'owner' to be a dict")
        pulumi.set(__self__, "owner", owner)
        if pipeline_schedule_id and not isinstance(pipeline_schedule_id, int):
            raise TypeError("Expected argument 'pipeline_schedule_id' to be a int")
        pulumi.set(__self__, "pipeline_schedule_id", pipeline_schedule_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if variables and not isinstance(variables, list):
            raise TypeError("Expected argument 'variables' to be a list")
        pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter
    def active(self) -> bool:
        """
        The activation status of pipeline schedule.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        The datetime of when the schedule was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def cron(self) -> str:
        """
        The cron (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "cron")

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> str:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the pipeline schedule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastPipeline")
    def last_pipeline(self) -> 'outputs.GetPipelineScheduleLastPipelineResult':
        """
        The details of the last pipeline run by the schedule.
        """
        return pulumi.get(self, "last_pipeline")

    @property
    @pulumi.getter(name="nextRunAt")
    def next_run_at(self) -> str:
        """
        The datetime of when the schedule will next run.
        """
        return pulumi.get(self, "next_run_at")

    @property
    @pulumi.getter
    def owner(self) -> 'outputs.GetPipelineScheduleOwnerResult':
        """
        The details of the pipeline schedule owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> int:
        """
        The pipeline schedule id.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The name or id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def ref(self) -> str:
        """
        The branch/tag name to be triggered. This will be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        The datetime of when the schedule was last updated.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def variables(self) -> Sequence['outputs.GetPipelineScheduleVariableResult']:
        """
        The list of the pipeline schedule variables.
        """
        return pulumi.get(self, "variables")


class AwaitableGetPipelineScheduleResult(GetPipelineScheduleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPipelineScheduleResult(
            active=self.active,
            created_at=self.created_at,
            cron=self.cron,
            cron_timezone=self.cron_timezone,
            description=self.description,
            id=self.id,
            last_pipeline=self.last_pipeline,
            next_run_at=self.next_run_at,
            owner=self.owner,
            pipeline_schedule_id=self.pipeline_schedule_id,
            project=self.project,
            ref=self.ref,
            updated_at=self.updated_at,
            variables=self.variables)


def get_pipeline_schedule(cron_timezone: Optional[str] = None,
                          pipeline_schedule_id: Optional[int] = None,
                          project: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPipelineScheduleResult:
    """
    The `PipelineSchedule` data source retrieves information about a gitlab pipeline schedule for a project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_pipeline_schedule(project="12345",
        pipeline_schedule_id=1)
    ```


    :param str cron_timezone: The timezone.
    :param int pipeline_schedule_id: The pipeline schedule id.
    :param str project: The name or id of the project to add the schedule to.
    """
    __args__ = dict()
    __args__['cronTimezone'] = cron_timezone
    __args__['pipelineScheduleId'] = pipeline_schedule_id
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getPipelineSchedule:getPipelineSchedule', __args__, opts=opts, typ=GetPipelineScheduleResult).value

    return AwaitableGetPipelineScheduleResult(
        active=pulumi.get(__ret__, 'active'),
        created_at=pulumi.get(__ret__, 'created_at'),
        cron=pulumi.get(__ret__, 'cron'),
        cron_timezone=pulumi.get(__ret__, 'cron_timezone'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        last_pipeline=pulumi.get(__ret__, 'last_pipeline'),
        next_run_at=pulumi.get(__ret__, 'next_run_at'),
        owner=pulumi.get(__ret__, 'owner'),
        pipeline_schedule_id=pulumi.get(__ret__, 'pipeline_schedule_id'),
        project=pulumi.get(__ret__, 'project'),
        ref=pulumi.get(__ret__, 'ref'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        variables=pulumi.get(__ret__, 'variables'))
def get_pipeline_schedule_output(cron_timezone: Optional[pulumi.Input[Optional[str]]] = None,
                                 pipeline_schedule_id: Optional[pulumi.Input[int]] = None,
                                 project: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPipelineScheduleResult]:
    """
    The `PipelineSchedule` data source retrieves information about a gitlab pipeline schedule for a project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_pipeline_schedule(project="12345",
        pipeline_schedule_id=1)
    ```


    :param str cron_timezone: The timezone.
    :param int pipeline_schedule_id: The pipeline schedule id.
    :param str project: The name or id of the project to add the schedule to.
    """
    __args__ = dict()
    __args__['cronTimezone'] = cron_timezone
    __args__['pipelineScheduleId'] = pipeline_schedule_id
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getPipelineSchedule:getPipelineSchedule', __args__, opts=opts, typ=GetPipelineScheduleResult)
    return __ret__.apply(lambda __response__: GetPipelineScheduleResult(
        active=pulumi.get(__response__, 'active'),
        created_at=pulumi.get(__response__, 'created_at'),
        cron=pulumi.get(__response__, 'cron'),
        cron_timezone=pulumi.get(__response__, 'cron_timezone'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        last_pipeline=pulumi.get(__response__, 'last_pipeline'),
        next_run_at=pulumi.get(__response__, 'next_run_at'),
        owner=pulumi.get(__response__, 'owner'),
        pipeline_schedule_id=pulumi.get(__response__, 'pipeline_schedule_id'),
        project=pulumi.get(__response__, 'project'),
        ref=pulumi.get(__response__, 'ref'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        variables=pulumi.get(__response__, 'variables')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupBillableMemberMembershipsResult',
    'AwaitableGetGroupBillableMemberMembershipsResult',
    'get_group_billable_member_memberships',
    'get_group_billable_member_memberships_output',
]

@pulumi.output_type
class GetGroupBillableMemberMembershipsResult:
    """
    A collection of values returned by getGroupBillableMemberMemberships.
    """
    def __init__(__self__, group_id=None, id=None, memberships=None, user_id=None):
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if memberships and not isinstance(memberships, list):
            raise TypeError("Expected argument 'memberships' to be a list")
        pulumi.set(__self__, "memberships", memberships)
        if user_id and not isinstance(user_id, int):
            raise TypeError("Expected argument 'user_id' to be a int")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        """
        The ID of the group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The id of the data source. It will always be equal to the user_id
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def memberships(self) -> Sequence['outputs.GetGroupBillableMemberMembershipsMembershipResult']:
        """
        group- and/or project-memberships of the user.
        """
        return pulumi.get(self, "memberships")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> int:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetGroupBillableMemberMembershipsResult(GetGroupBillableMemberMembershipsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupBillableMemberMembershipsResult(
            group_id=self.group_id,
            id=self.id,
            memberships=self.memberships,
            user_id=self.user_id)


def get_group_billable_member_memberships(group_id: Optional[str] = None,
                                          user_id: Optional[int] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupBillableMemberMembershipsResult:
    """
    The `get_group_billable_member_memberships` data source allows (sub)group- and project-memberships of a billable member of a group to be retrieved by either the user ID, username or email address.

    > You must be an administrator!

    > When using the `email` attribute, an exact match is not guaranteed. The most related match will be returned. Starting with GitLab 16.6,
    the most related match will prioritize an exact match if one is available.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/members/#list-memberships-for-a-billable-member-of-a-group)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    test_user_membership = gitlab.get_group_billable_member_memberships(user_id=21,
        group_id="42")
    ```


    :param str group_id: The ID of the group.
    :param int user_id: The ID of the user.
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupBillableMemberMemberships:getGroupBillableMemberMemberships', __args__, opts=opts, typ=GetGroupBillableMemberMembershipsResult).value

    return AwaitableGetGroupBillableMemberMembershipsResult(
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        memberships=pulumi.get(__ret__, 'memberships'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_group_billable_member_memberships_output(group_id: Optional[pulumi.Input[str]] = None,
                                                 user_id: Optional[pulumi.Input[int]] = None,
                                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupBillableMemberMembershipsResult]:
    """
    The `get_group_billable_member_memberships` data source allows (sub)group- and project-memberships of a billable member of a group to be retrieved by either the user ID, username or email address.

    > You must be an administrator!

    > When using the `email` attribute, an exact match is not guaranteed. The most related match will be returned. Starting with GitLab 16.6,
    the most related match will prioritize an exact match if one is available.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/members/#list-memberships-for-a-billable-member-of-a-group)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    test_user_membership = gitlab.get_group_billable_member_memberships(user_id=21,
        group_id="42")
    ```


    :param str group_id: The ID of the group.
    :param int user_id: The ID of the user.
    """
    __args__ = dict()
    __args__['groupId'] = group_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupBillableMemberMemberships:getGroupBillableMemberMemberships', __args__, opts=opts, typ=GetGroupBillableMemberMembershipsResult)
    return __ret__.apply(lambda __response__: GetGroupBillableMemberMembershipsResult(
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id'),
        memberships=pulumi.get(__response__, 'memberships'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, avatar_url=None, bio=None, can_create_group=None, can_create_project=None, color_scheme_id=None, created_at=None, current_sign_in_at=None, email=None, extern_uid=None, external=None, id=None, is_admin=None, is_bot=None, last_sign_in_at=None, linkedin=None, location=None, name=None, namespace_id=None, note=None, organization=None, projects_limit=None, skype=None, state=None, theme_id=None, twitter=None, two_factor_enabled=None, user_id=None, user_provider=None, username=None, website_url=None):
        if avatar_url and not isinstance(avatar_url, str):
            raise TypeError("Expected argument 'avatar_url' to be a str")
        pulumi.set(__self__, "avatar_url", avatar_url)
        if bio and not isinstance(bio, str):
            raise TypeError("Expected argument 'bio' to be a str")
        pulumi.set(__self__, "bio", bio)
        if can_create_group and not isinstance(can_create_group, bool):
            raise TypeError("Expected argument 'can_create_group' to be a bool")
        pulumi.set(__self__, "can_create_group", can_create_group)
        if can_create_project and not isinstance(can_create_project, bool):
            raise TypeError("Expected argument 'can_create_project' to be a bool")
        pulumi.set(__self__, "can_create_project", can_create_project)
        if color_scheme_id and not isinstance(color_scheme_id, int):
            raise TypeError("Expected argument 'color_scheme_id' to be a int")
        pulumi.set(__self__, "color_scheme_id", color_scheme_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if current_sign_in_at and not isinstance(current_sign_in_at, str):
            raise TypeError("Expected argument 'current_sign_in_at' to be a str")
        pulumi.set(__self__, "current_sign_in_at", current_sign_in_at)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if extern_uid and not isinstance(extern_uid, str):
            raise TypeError("Expected argument 'extern_uid' to be a str")
        pulumi.set(__self__, "extern_uid", extern_uid)
        if external and not isinstance(external, bool):
            raise TypeError("Expected argument 'external' to be a bool")
        pulumi.set(__self__, "external", external)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_admin and not isinstance(is_admin, bool):
            raise TypeError("Expected argument 'is_admin' to be a bool")
        pulumi.set(__self__, "is_admin", is_admin)
        if is_bot and not isinstance(is_bot, bool):
            raise TypeError("Expected argument 'is_bot' to be a bool")
        pulumi.set(__self__, "is_bot", is_bot)
        if last_sign_in_at and not isinstance(last_sign_in_at, str):
            raise TypeError("Expected argument 'last_sign_in_at' to be a str")
        pulumi.set(__self__, "last_sign_in_at", last_sign_in_at)
        if linkedin and not isinstance(linkedin, str):
            raise TypeError("Expected argument 'linkedin' to be a str")
        pulumi.set(__self__, "linkedin", linkedin)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace_id and not isinstance(namespace_id, int):
            raise TypeError("Expected argument 'namespace_id' to be a int")
        pulumi.set(__self__, "namespace_id", namespace_id)
        if note and not isinstance(note, str):
            raise TypeError("Expected argument 'note' to be a str")
        pulumi.set(__self__, "note", note)
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        pulumi.set(__self__, "organization", organization)
        if projects_limit and not isinstance(projects_limit, int):
            raise TypeError("Expected argument 'projects_limit' to be a int")
        pulumi.set(__self__, "projects_limit", projects_limit)
        if skype and not isinstance(skype, str):
            raise TypeError("Expected argument 'skype' to be a str")
        pulumi.set(__self__, "skype", skype)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if theme_id and not isinstance(theme_id, int):
            raise TypeError("Expected argument 'theme_id' to be a int")
        pulumi.set(__self__, "theme_id", theme_id)
        if twitter and not isinstance(twitter, str):
            raise TypeError("Expected argument 'twitter' to be a str")
        pulumi.set(__self__, "twitter", twitter)
        if two_factor_enabled and not isinstance(two_factor_enabled, bool):
            raise TypeError("Expected argument 'two_factor_enabled' to be a bool")
        pulumi.set(__self__, "two_factor_enabled", two_factor_enabled)
        if user_id and not isinstance(user_id, int):
            raise TypeError("Expected argument 'user_id' to be a int")
        pulumi.set(__self__, "user_id", user_id)
        if user_provider and not isinstance(user_provider, str):
            raise TypeError("Expected argument 'user_provider' to be a str")
        pulumi.set(__self__, "user_provider", user_provider)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)
        if website_url and not isinstance(website_url, str):
            raise TypeError("Expected argument 'website_url' to be a str")
        pulumi.set(__self__, "website_url", website_url)

    @property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> str:
        """
        The avatar URL of the user.
        """
        return pulumi.get(self, "avatar_url")

    @property
    @pulumi.getter
    def bio(self) -> str:
        """
        The bio of the user.
        """
        return pulumi.get(self, "bio")

    @property
    @pulumi.getter(name="canCreateGroup")
    def can_create_group(self) -> bool:
        """
        Whether the user can create groups.
        """
        return pulumi.get(self, "can_create_group")

    @property
    @pulumi.getter(name="canCreateProject")
    def can_create_project(self) -> bool:
        """
        Whether the user can create projects.
        """
        return pulumi.get(self, "can_create_project")

    @property
    @pulumi.getter(name="colorSchemeId")
    def color_scheme_id(self) -> int:
        """
        User's color scheme ID.
        """
        return pulumi.get(self, "color_scheme_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date the user was created at.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentSignInAt")
    def current_sign_in_at(self) -> str:
        """
        Current user's sign-in date.
        """
        return pulumi.get(self, "current_sign_in_at")

    @property
    @pulumi.getter
    def email(self) -> str:
        """
        The public email address of the user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="externUid")
    def extern_uid(self) -> str:
        """
        The external UID of the user.
        """
        return pulumi.get(self, "extern_uid")

    @property
    @pulumi.getter
    def external(self) -> bool:
        """
        Whether the user is external.
        """
        return pulumi.get(self, "external")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isAdmin")
    def is_admin(self) -> bool:
        """
        Whether the user is an admin.
        """
        return pulumi.get(self, "is_admin")

    @property
    @pulumi.getter(name="isBot")
    def is_bot(self) -> bool:
        """
        Whether the user is a bot.
        """
        return pulumi.get(self, "is_bot")

    @property
    @pulumi.getter(name="lastSignInAt")
    def last_sign_in_at(self) -> str:
        """
        Last user's sign-in date.
        """
        return pulumi.get(self, "last_sign_in_at")

    @property
    @pulumi.getter
    def linkedin(self) -> str:
        """
        LinkedIn profile of the user.
        """
        return pulumi.get(self, "linkedin")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The location of the user.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> int:
        """
        The ID of the user's namespace. Requires admin token to access this field.
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter
    def note(self) -> str:
        """
        Admin notes for this user.
        """
        return pulumi.get(self, "note")

    @property
    @pulumi.getter
    def organization(self) -> str:
        """
        The organization of the user.
        """
        return pulumi.get(self, "organization")

    @property
    @pulumi.getter(name="projectsLimit")
    def projects_limit(self) -> int:
        """
        Number of projects the user can create.
        """
        return pulumi.get(self, "projects_limit")

    @property
    @pulumi.getter
    def skype(self) -> str:
        """
        Skype username of the user.
        """
        return pulumi.get(self, "skype")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        Whether the user is active or blocked.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> int:
        """
        User's theme ID.
        """
        return pulumi.get(self, "theme_id")

    @property
    @pulumi.getter
    def twitter(self) -> str:
        """
        Twitter username of the user.
        """
        return pulumi.get(self, "twitter")

    @property
    @pulumi.getter(name="twoFactorEnabled")
    def two_factor_enabled(self) -> bool:
        """
        Whether user's two-factor auth is enabled.
        """
        return pulumi.get(self, "two_factor_enabled")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> int:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="userProvider")
    def user_provider(self) -> str:
        """
        The UID provider of the user.
        """
        return pulumi.get(self, "user_provider")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The username of the user.
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="websiteUrl")
    def website_url(self) -> str:
        """
        User's website URL.
        """
        return pulumi.get(self, "website_url")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            avatar_url=self.avatar_url,
            bio=self.bio,
            can_create_group=self.can_create_group,
            can_create_project=self.can_create_project,
            color_scheme_id=self.color_scheme_id,
            created_at=self.created_at,
            current_sign_in_at=self.current_sign_in_at,
            email=self.email,
            extern_uid=self.extern_uid,
            external=self.external,
            id=self.id,
            is_admin=self.is_admin,
            is_bot=self.is_bot,
            last_sign_in_at=self.last_sign_in_at,
            linkedin=self.linkedin,
            location=self.location,
            name=self.name,
            namespace_id=self.namespace_id,
            note=self.note,
            organization=self.organization,
            projects_limit=self.projects_limit,
            skype=self.skype,
            state=self.state,
            theme_id=self.theme_id,
            twitter=self.twitter,
            two_factor_enabled=self.two_factor_enabled,
            user_id=self.user_id,
            user_provider=self.user_provider,
            username=self.username,
            website_url=self.website_url)


def get_user(email: Optional[str] = None,
             namespace_id: Optional[int] = None,
             user_id: Optional[int] = None,
             username: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    The `User` data source allows details of a user to be retrieved by either the user ID, username or email address.

    > Some attributes might not be returned depending on if you're an admin or not.

    > When using the `email` attribute, an exact match is not guaranteed. The most related match will be returned. The most related match will prioritize an exact match if one is available.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/users/#single-user)


    :param str email: The public email address of the user.
    :param int namespace_id: The ID of the user's namespace. Requires admin token to access this field.
    :param int user_id: The ID of the user.
    :param str username: The username of the user.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['namespaceId'] = namespace_id
    __args__['userId'] = user_id
    __args__['username'] = username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        avatar_url=pulumi.get(__ret__, 'avatar_url'),
        bio=pulumi.get(__ret__, 'bio'),
        can_create_group=pulumi.get(__ret__, 'can_create_group'),
        can_create_project=pulumi.get(__ret__, 'can_create_project'),
        color_scheme_id=pulumi.get(__ret__, 'color_scheme_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        current_sign_in_at=pulumi.get(__ret__, 'current_sign_in_at'),
        email=pulumi.get(__ret__, 'email'),
        extern_uid=pulumi.get(__ret__, 'extern_uid'),
        external=pulumi.get(__ret__, 'external'),
        id=pulumi.get(__ret__, 'id'),
        is_admin=pulumi.get(__ret__, 'is_admin'),
        is_bot=pulumi.get(__ret__, 'is_bot'),
        last_sign_in_at=pulumi.get(__ret__, 'last_sign_in_at'),
        linkedin=pulumi.get(__ret__, 'linkedin'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        namespace_id=pulumi.get(__ret__, 'namespace_id'),
        note=pulumi.get(__ret__, 'note'),
        organization=pulumi.get(__ret__, 'organization'),
        projects_limit=pulumi.get(__ret__, 'projects_limit'),
        skype=pulumi.get(__ret__, 'skype'),
        state=pulumi.get(__ret__, 'state'),
        theme_id=pulumi.get(__ret__, 'theme_id'),
        twitter=pulumi.get(__ret__, 'twitter'),
        two_factor_enabled=pulumi.get(__ret__, 'two_factor_enabled'),
        user_id=pulumi.get(__ret__, 'user_id'),
        user_provider=pulumi.get(__ret__, 'user_provider'),
        username=pulumi.get(__ret__, 'username'),
        website_url=pulumi.get(__ret__, 'website_url'))
def get_user_output(email: Optional[pulumi.Input[Optional[str]]] = None,
                    namespace_id: Optional[pulumi.Input[Optional[int]]] = None,
                    user_id: Optional[pulumi.Input[Optional[int]]] = None,
                    username: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    The `User` data source allows details of a user to be retrieved by either the user ID, username or email address.

    > Some attributes might not be returned depending on if you're an admin or not.

    > When using the `email` attribute, an exact match is not guaranteed. The most related match will be returned. The most related match will prioritize an exact match if one is available.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/users/#single-user)


    :param str email: The public email address of the user.
    :param int namespace_id: The ID of the user's namespace. Requires admin token to access this field.
    :param int user_id: The ID of the user.
    :param str username: The username of the user.
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['namespaceId'] = namespace_id
    __args__['userId'] = user_id
    __args__['username'] = username
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        avatar_url=pulumi.get(__response__, 'avatar_url'),
        bio=pulumi.get(__response__, 'bio'),
        can_create_group=pulumi.get(__response__, 'can_create_group'),
        can_create_project=pulumi.get(__response__, 'can_create_project'),
        color_scheme_id=pulumi.get(__response__, 'color_scheme_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        current_sign_in_at=pulumi.get(__response__, 'current_sign_in_at'),
        email=pulumi.get(__response__, 'email'),
        extern_uid=pulumi.get(__response__, 'extern_uid'),
        external=pulumi.get(__response__, 'external'),
        id=pulumi.get(__response__, 'id'),
        is_admin=pulumi.get(__response__, 'is_admin'),
        is_bot=pulumi.get(__response__, 'is_bot'),
        last_sign_in_at=pulumi.get(__response__, 'last_sign_in_at'),
        linkedin=pulumi.get(__response__, 'linkedin'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        namespace_id=pulumi.get(__response__, 'namespace_id'),
        note=pulumi.get(__response__, 'note'),
        organization=pulumi.get(__response__, 'organization'),
        projects_limit=pulumi.get(__response__, 'projects_limit'),
        skype=pulumi.get(__response__, 'skype'),
        state=pulumi.get(__response__, 'state'),
        theme_id=pulumi.get(__response__, 'theme_id'),
        twitter=pulumi.get(__response__, 'twitter'),
        two_factor_enabled=pulumi.get(__response__, 'two_factor_enabled'),
        user_id=pulumi.get(__response__, 'user_id'),
        user_provider=pulumi.get(__response__, 'user_provider'),
        username=pulumi.get(__response__, 'username'),
        website_url=pulumi.get(__response__, 'website_url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PipelineScheduleArgs', 'PipelineSchedule']

@pulumi.input_type
class PipelineScheduleArgs:
    def __init__(__self__, *,
                 cron: pulumi.Input[str],
                 description: pulumi.Input[str],
                 project: pulumi.Input[str],
                 ref: pulumi.Input[str],
                 active: Optional[pulumi.Input[bool]] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 take_ownership: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a PipelineSchedule resource.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron_timezone: The timezone.
        """
        pulumi.set(__self__, "cron", cron)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "ref", ref)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if cron_timezone is not None:
            pulumi.set(__self__, "cron_timezone", cron_timezone)
        if take_ownership is not None:
            pulumi.set(__self__, "take_ownership", take_ownership)

    @property
    @pulumi.getter
    def cron(self) -> pulumi.Input[str]:
        """
        The cron (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: pulumi.Input[str]):
        pulumi.set(self, "cron", value)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        The description of the pipeline schedule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The name or id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def ref(self) -> pulumi.Input[str]:
        """
        The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        return pulumi.get(self, "ref")

    @ref.setter
    def ref(self, value: pulumi.Input[str]):
        pulumi.set(self, "ref", value)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> Optional[pulumi.Input[str]]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @cron_timezone.setter
    def cron_timezone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron_timezone", value)

    @property
    @pulumi.getter(name="takeOwnership")
    def take_ownership(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "take_ownership")

    @take_ownership.setter
    def take_ownership(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "take_ownership", value)


@pulumi.input_type
class _PipelineScheduleState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 cron: Optional[pulumi.Input[str]] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[int]] = None,
                 pipeline_schedule_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 ref: Optional[pulumi.Input[str]] = None,
                 take_ownership: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering PipelineSchedule resources.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[int] owner: The ID of the user that owns the pipeline schedule.
        :param pulumi.Input[int] pipeline_schedule_id: The pipeline schedule id.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if cron is not None:
            pulumi.set(__self__, "cron", cron)
        if cron_timezone is not None:
            pulumi.set(__self__, "cron_timezone", cron_timezone)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if pipeline_schedule_id is not None:
            pulumi.set(__self__, "pipeline_schedule_id", pipeline_schedule_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if ref is not None:
            pulumi.set(__self__, "ref", ref)
        if take_ownership is not None:
            pulumi.set(__self__, "take_ownership", take_ownership)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter
    def cron(self) -> Optional[pulumi.Input[str]]:
        """
        The cron (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron", value)

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> Optional[pulumi.Input[str]]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @cron_timezone.setter
    def cron_timezone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron_timezone", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the pipeline schedule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the user that owns the pipeline schedule.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> Optional[pulumi.Input[int]]:
        """
        The pipeline schedule id.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @pipeline_schedule_id.setter
    def pipeline_schedule_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "pipeline_schedule_id", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def ref(self) -> Optional[pulumi.Input[str]]:
        """
        The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        return pulumi.get(self, "ref")

    @ref.setter
    def ref(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ref", value)

    @property
    @pulumi.getter(name="takeOwnership")
    def take_ownership(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "take_ownership")

    @take_ownership.setter
    def take_ownership(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "take_ownership", value)


class PipelineSchedule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 cron: Optional[pulumi.Input[str]] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 ref: Optional[pulumi.Input[str]] = None,
                 take_ownership: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        The `PipelineSchedule` resource allows to manage the lifecycle of a scheduled pipeline.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineSchedule("example",
            project="12345",
            description="Used to schedule builds",
            ref="refs/heads/main",
            cron="0 1 * * *")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_pipeline_schedule`. For example:

        terraform

        import {

          to = gitlab_pipeline_schedule.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab pipeline schedules can be imported using an id made up of `{project_id}:{pipeline_schedule_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineSchedule:PipelineSchedule test 1:3
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineScheduleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `PipelineSchedule` resource allows to manage the lifecycle of a scheduled pipeline.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineSchedule("example",
            project="12345",
            description="Used to schedule builds",
            ref="refs/heads/main",
            cron="0 1 * * *")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_pipeline_schedule`. For example:

        terraform

        import {

          to = gitlab_pipeline_schedule.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab pipeline schedules can be imported using an id made up of `{project_id}:{pipeline_schedule_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineSchedule:PipelineSchedule test 1:3
        ```

        :param str resource_name: The name of the resource.
        :param PipelineScheduleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineScheduleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[bool]] = None,
                 cron: Optional[pulumi.Input[str]] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 ref: Optional[pulumi.Input[str]] = None,
                 take_ownership: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineScheduleArgs.__new__(PipelineScheduleArgs)

            __props__.__dict__["active"] = active
            if cron is None and not opts.urn:
                raise TypeError("Missing required property 'cron'")
            __props__.__dict__["cron"] = cron
            __props__.__dict__["cron_timezone"] = cron_timezone
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if ref is None and not opts.urn:
                raise TypeError("Missing required property 'ref'")
            __props__.__dict__["ref"] = ref
            __props__.__dict__["take_ownership"] = take_ownership
            __props__.__dict__["owner"] = None
            __props__.__dict__["pipeline_schedule_id"] = None
        super(PipelineSchedule, __self__).__init__(
            'gitlab:index/pipelineSchedule:PipelineSchedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            cron: Optional[pulumi.Input[str]] = None,
            cron_timezone: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[int]] = None,
            pipeline_schedule_id: Optional[pulumi.Input[int]] = None,
            project: Optional[pulumi.Input[str]] = None,
            ref: Optional[pulumi.Input[str]] = None,
            take_ownership: Optional[pulumi.Input[bool]] = None) -> 'PipelineSchedule':
        """
        Get an existing PipelineSchedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[int] owner: The ID of the user that owns the pipeline schedule.
        :param pulumi.Input[int] pipeline_schedule_id: The pipeline schedule id.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineScheduleState.__new__(_PipelineScheduleState)

        __props__.__dict__["active"] = active
        __props__.__dict__["cron"] = cron
        __props__.__dict__["cron_timezone"] = cron_timezone
        __props__.__dict__["description"] = description
        __props__.__dict__["owner"] = owner
        __props__.__dict__["pipeline_schedule_id"] = pipeline_schedule_id
        __props__.__dict__["project"] = project
        __props__.__dict__["ref"] = ref
        __props__.__dict__["take_ownership"] = take_ownership
        return PipelineSchedule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[bool]:
        """
        The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter
    def cron(self) -> pulumi.Output[str]:
        """
        The cron (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "cron")

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> pulumi.Output[str]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        The description of the pipeline schedule.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[int]:
        """
        The ID of the user that owns the pipeline schedule.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> pulumi.Output[int]:
        """
        The pipeline schedule id.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The name or id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def ref(self) -> pulumi.Output[str]:
        """
        The branch/tag name to be triggered. This must be the full branch reference, for example: `refs/heads/main`, not `main`.
        """
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter(name="takeOwnership")
    def take_ownership(self) -> pulumi.Output[bool]:
        return pulumi.get(self, "take_ownership")

